@@ -208,37 +208,37 @@ Log info message.
 
 =head2 is_level
 
-  my $success = $log->is_level('debug');
+  my $bool = $log->is_level('debug');
 
 Check log level.
 
 =head2 is_debug
 
-  my $success = $log->is_debug;
+  my $bool = $log->is_debug;
 
 Check for debug log level.
 
 =head2 is_error
 
-  my $success = $log->is_error;
+  my $bool = $log->is_error;
 
 Check for error log level.
 
 =head2 is_fatal
 
-  my $success = $log->is_fatal;
+  my $bool = $log->is_fatal;
 
 Check for fatal log level.
 
 =head2 is_info
 
-  my $success = $log->is_info;
+  my $bool = $log->is_info;
 
 Check for info log level.
 
 =head2 is_warn
 
-  my $success = $log->is_warn;
+  my $bool = $log->is_warn;
 
 Check for warn log level.
 
