@@ -14,7 +14,7 @@ use Mojo::Util 'decode';
 has content => sub { Mojo::Content::Single->new };
 has default_charset  => 'UTF-8';
 has max_line_size    => sub { $ENV{MOJO_MAX_LINE_SIZE} || 10240 };
-has max_message_size => sub { $ENV{MOJO_MAX_MESSAGE_SIZE} || 10485760 };
+has max_message_size => sub { $ENV{MOJO_MAX_MESSAGE_SIZE} // 10485760 };
 has version          => '1.1';
 
 sub body {
@@ -153,8 +153,9 @@ sub parse {
   my ($self, $chunk) = @_;
 
   # Check message size
+  my $max = $self->max_message_size;
   return $self->_limit('Maximum message size exceeded', 413)
-    if ($self->{raw_size} += length($chunk //= '')) > $self->max_message_size;
+    if $max && ($self->{raw_size} += length($chunk //= '')) > $max;
 
   $self->{buffer} .= $chunk;
 
@@ -392,10 +393,11 @@ MOJO_MAX_LINE_SIZE environment variable or C<10240>.
   $msg     = $msg->max_message_size(1024);
 
 Maximum message size in bytes, defaults to the value of the
-MOJO_MAX_MESSAGE_SIZE environment variable or C<10485760>. Note that
-increasing this value can also drastically increase memory usage, should you
-for example attempt to parse an excessively large message body with the
-C<body_params>, C<dom> or C<json> methods.
+MOJO_MAX_MESSAGE_SIZE environment variable or C<10485760>. Setting the value
+to C<0> will allow messages of indefinite size. Note that increasing this
+value can also drastically increase memory usage, should you for example
+attempt to parse an excessively large message body with the C<body_params>,
+C<dom> or C<json> methods.
 
 =head2 version
 
