@@ -24,7 +24,7 @@ sub render {
 
   # Application instance and helper
   my $prepend = q[my $app = shift; no strict 'refs'; no warnings 'redefine';];
-  $prepend .= q[sub app; *app = sub { $app }; use Mojo::Base -strict;];
+  $prepend .= q[sub app; local *app = sub { $app }; use Mojo::Base -strict;];
 
   # Render and encode for JSON decoding
   my $mt = Mojo::Template->new($conf->{template} || {})->name($file);
